@@ -168,6 +168,18 @@ class TestCloudConfig(base.TestCase):
             auth=mock.ANY,
             verify=True, cert=None, timeout=None)
 
+    @mock.patch.object(ksa_session, 'Session')
+    def test_get_session_with_timeout(self, mock_session):
+        config_dict = defaults.get_defaults()
+        config_dict.update(fake_services_dict)
+        config_dict['api_timeout'] = 9
+        cc = cloud_config.CloudConfig(
+            "test1", "region-al", config_dict, auth_plugin=mock.Mock())
+        cc.get_session()
+        mock_session.assert_called_with(
+            auth=mock.ANY,
+            verify=True, cert=None, timeout=9)
+
     @mock.patch.object(ksa_session, 'Session')
     def test_override_session_endpoint(self, mock_session):
         config_dict = defaults.get_defaults()
@@ -214,6 +226,27 @@ class TestCloudConfig(base.TestCase):
         cc = cloud_config.CloudConfig(
             "test1", "region-al", config_dict, auth_plugin=mock.Mock())
         cc.get_legacy_client('object-store', mock_client)
+        mock_client.assert_called_with(
+            preauthtoken=mock.ANY,
+            os_options={
+                'auth_token': mock.ANY,
+                'region_name': 'region-al',
+                'object_storage_url': 'http://example.com/v2'
+            },
+            preauthurl='http://example.com/v2',
+            auth_version='2.0')
+
+    @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
+    def test_legacy_client_object_store_timeout(
+            self, mock_get_session_endpoint):
+        mock_client = mock.Mock()
+        mock_get_session_endpoint.return_value = 'http://example.com/v2'
+        config_dict = defaults.get_defaults()
+        config_dict.update(fake_services_dict)
+        config_dict['api_timeout'] = 9
+        cc = cloud_config.CloudConfig(
+            "test1", "region-al", config_dict, auth_plugin=mock.Mock())
+        cc.get_legacy_client('object-store', mock_client)
         mock_client.assert_called_with(
             preauthtoken=mock.ANY,
             os_options={
@@ -223,7 +256,25 @@ class TestCloudConfig(base.TestCase):
             },
             preauthurl='http://example.com/v2',
             auth_version='2.0',
-            timeout=None)
+            timeout=9.0)
+
+    def test_legacy_client_object_store_endpoint(self):
+        mock_client = mock.Mock()
+        config_dict = defaults.get_defaults()
+        config_dict.update(fake_services_dict)
+        config_dict['object_store_endpoint'] = 'http://example.com/v2'
+        cc = cloud_config.CloudConfig(
+            "test1", "region-al", config_dict, auth_plugin=mock.Mock())
+        cc.get_legacy_client('object-store', mock_client)
+        mock_client.assert_called_with(
+            preauthtoken=mock.ANY,
+            os_options={
+                'auth_token': mock.ANY,
+                'region_name': 'region-al',
+                'object_storage_url': 'http://example.com/v2'
+            },
+            preauthurl='http://example.com/v2',
+            auth_version='2.0')
 
     @mock.patch.object(cloud_config.CloudConfig, 'get_session_endpoint')
     def test_legacy_client_image(self, mock_get_session_endpoint):
@@ -289,7 +340,7 @@ class TestCloudConfig(base.TestCase):
             "test1", "region-al", config_dict, auth_plugin=mock.Mock())
         cc.get_legacy_client('identity', mock_client)
         mock_client.assert_called_with(
-            version=('2', '0'),
+            '2.0',
             endpoint='http://example.com/v2',
             endpoint_type='admin',
             region_name='region-al',
@@ -308,7 +359,7 @@ class TestCloudConfig(base.TestCase):
             "test1", "region-al", config_dict, auth_plugin=mock.Mock())
         cc.get_legacy_client('identity', mock_client)
         mock_client.assert_called_with(
-            version=('3', '0'),
+            '3',
             endpoint='http://example.com',
             endpoint_type='admin',
             region_name='region-al',
